@@ -47,6 +47,10 @@ def variable_operation(
             raise JMCSyntaxException(
                 f"Duplicated operator({operator})", list_of_tokens[2][-1], tokenizer)
 
+        if len(list_of_tokens[0]) > 1:
+            raise JMCSyntaxException(
+                f"Unexpected token ('{list_of_tokens[0][1].string}') after variable ('{list_of_tokens[0][0].string}')", list_of_tokens[0][1], tokenizer, suggestion="Expected operator")
+
         if operator in {'++', '--'}:
             if list_of_tokens[1]:
                 raise JMCSyntaxException(
@@ -60,6 +64,10 @@ def variable_operation(
             if operator == '--':
                 return f"scoreboard players remove {list_of_tokens[0][0].string} {DataPack.var_name} 1"
 
+        if not list_of_tokens[1]:
+            raise JMCSyntaxException(
+                f"Expected token after an operator('{operator}')", tokens[-1], tokenizer, suggestion="Expected integer or variable or target selector")
+
         if operator == '=' and list_of_tokens[1][0].token_type == TokenType.KEYWORD and list_of_tokens[1][0].string in VAR_OPERATION_COMMANDS:
             if len(list_of_tokens[1]) == 1:
                 raise JMCSyntaxException(
