@@ -51,8 +51,10 @@ class Token:
         """
         header = Header()
         if self.token_type == TokenType.PAREN_CURLY:
-            if not self.string.startswith('{') or not self.string.endswith('}'):
-                raise ValueError("paren_curly Token created but string doesn't start and end with the parenthesis")
+            if not self.string.startswith(
+                    '{') or not self.string.endswith('}'):
+                raise ValueError(
+                    "paren_curly Token created but string doesn't start and end with the parenthesis")
 
         if self.token_type != TokenType.KEYWORD:
             return
@@ -370,12 +372,16 @@ class Tokenizer:
                 continue
 
             if char == Re.SLASH and self.is_slash and self.state != TokenType.PAREN:
-                self.state = TokenType.COMMENT
                 self.token = self.token[:-1]
+                if self.token:
+                    self.append_token()
+                self.state = TokenType.COMMENT
                 continue
 
             if self.state == TokenType.KEYWORD:
+
                 if self.__parse_keyword(char):
+                    self.is_slash = (char == Re.SLASH)
                     continue
 
             if self.state is None:
@@ -433,6 +439,9 @@ class Tokenizer:
 
         self.__parse_chars(string, expect_semicolon)
 
+        # if self.state == TokenType.COMMENT:
+        #     self.state = None
+
         if self.state == TokenType.STRING:
             raise JMCSyntaxException(
                 "String literal contains an unescaped line break", None, self, entire_line=True, display_col_length=False)
@@ -721,7 +730,7 @@ class Tokenizer:
 
             if expecting_comma and token.token_type != TokenType.COMMA:
                 raise JMCSyntaxException(
-                    f"Expected comma(,)", last_token, self)
+                    f"Expected comma(,)", last_token, self, col_length=True)
 
             if arrow_func_state > 0:
                 if arrow_func_state == 1:
@@ -738,7 +747,7 @@ class Tokenizer:
                 elif arrow_func_state == 2:
                     if token.token_type == TokenType.PAREN_CURLY:
                         new_token = Token(
-                            string=token.string[1:-1], line=token.line, col=token.col + 1, token_type=TokenType.FUNC)
+                            string=token.string, line=token.line, col=token.col + 1, token_type=TokenType.FUNC)
                         arg = new_token.string
                         if key:
                             add_kwarg(new_token)
